API Reference
=============

CLI
---

.. automodule:: ghud.cli
   :members:

Configuration
-------------

.. automodule:: ghud.config
   :members:

GitHub API
----------

.. automodule:: ghud.github
   :members:

Data Processing
---------------

.. automodule:: ghud.data
   :members:

Dashboard Rendering
-------------------

.. automodule:: ghud.dashboard
   :members:

Issue Rendering
---------------

.. automodule:: ghud.render_issue
   :members:

PR Rendering
------------

.. automodule:: ghud.render_pr
   :members:

Repo Rendering
--------------

.. automodule:: ghud.render_repo
   :members:

Repo Context
------------

.. automodule:: ghud.repo_context
   :members:

Pager
-----

.. automodule:: ghud.pager
   :members:

Discovery
---------

.. automodule:: ghud.discover
   :members:

MCP Server
----------

.. automodule:: ghud.mcp
   :members:
